@@ -144,8 +144,7 @@ class ThreeCommasWebsocket:
                 if (
                     "identifier" in message
                     and json.loads(message["identifier"])["channel"]
-                    == "DealsChannel"
-                    # == "SmartTradesChannel"
+                    in SocketChannelsTuple
                 ):
                     event = message["message"]
                     self.on_event(event)
@@ -159,7 +158,7 @@ class ThreeCommasWebsocket:
                     json.dumps({
                         "command": "subscribe",
                             "identifier": json.dumps(self.identifier),
-                    }
+                        }
                     )
                 )
             elif message["type"] == "confirm_subscription":
@@ -171,6 +170,7 @@ class ThreeCommasWebsocket:
             else:
                 _LOGGER.debug("Received unknown type: %s", message)
 
+        # Need better exception handling here
         except Exception as error:
             _LOGGER.exception(error)
 
